@@ -20,6 +20,7 @@ import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.impl.
 import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.impl.DeleteColumnAction;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.impl.NormalizeTableAction;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.impl.TimeAggregationAction;
+import org.gcube.data.analysis.tabulardata.commons.templates.model.actions.impl.ValidateExpressionAction;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.ColumnCategory;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.ColumnDescription;
 import org.gcube.data.analysis.tabulardata.commons.templates.model.columns.TemplateColumn;
@@ -407,7 +408,12 @@ public class ConverterToTdTemplateModel {
 			if(templateAction instanceof TimeAggregationAction){
 				TimeAggregationAction timeAction = (TimeAggregationAction) templateAction;
 
-				builder.append("Time Aggregation on "+timeAction.getColumn().getLabel()+"<br/>");
+				String description = "Time Aggregation"; 
+				String columnLabel = timeAction.getColumn().getLabel()!=null?timeAction.getColumn().getLabel():"";
+				if(!columnLabel.isEmpty())
+					description+= " on "+columnLabel;
+				builder.append(description+"<br/>");
+				
 				builder.append("for "+timeAction.getPeriodType().getName()+"<br/>");
 				builder.append("Grouping column/s:<br/>");
 				for (TemplateColumn<?> column : timeAction.getGroupColumns()) {
@@ -421,7 +427,13 @@ public class ConverterToTdTemplateModel {
 				tdDescr = new TabularDataActionDescription(timeAction.getIdentifier()+"", TimeAggregationAction.class.getSimpleName(), builder.toString());
 			}else if(templateAction instanceof AddColumnAction){
 				AddColumnAction addAction = (AddColumnAction) templateAction;
-				builder.append("Add Column Operation on "+addAction.getColumn().getLabel()+"<br/>");
+				
+				String description = "Add Column Operation"; 
+				String columnLabel = addAction.getColumn().getLabel()!=null?addAction.getColumn().getLabel():"";
+				if(!columnLabel.isEmpty())
+					description+= " on "+columnLabel;
+				builder.append(description+"<br/>");
+				
 				Expression initialValue = addAction.getInitialValue();
 				String readeable = "";
 				try{
@@ -445,14 +457,14 @@ public class ConverterToTdTemplateModel {
 				}
 				builder.append("Normalized Column/s: "+labels+"<br/>");
 				tdDescr = new TabularDataActionDescription(normalizeAction.getIdentifier()+"", NormalizeColumnsAction.class.getSimpleName(), builder.toString());
+			}else if(templateAction instanceof ValidateExpressionAction){
+				ValidateExpressionAction validateExpressionAction = (ValidateExpressionAction) templateAction;
+				builder.append("Table rule action: "+validateExpressionAction.getName());
+				//TODO ADD EXPRESSION
+//				ConverterToTdTemplateModel.convertRuleExpression(templateExpression.getClientExpression());
+				tdDescr = new TabularDataActionDescription(validateExpressionAction.getIdentifier()+"", ValidateExpressionAction.class.getSimpleName(), builder.toString());
 			}
-//			}else if(templateAction.getBelongsToGroup()!=null)
-//				
-////				if(templateAction instanceof GenerateTimeDimensionGroup)
-////				GenerateTimeDimensionGroup groupAction = (GenerateTimeDimensionGroup) templateAction;
-////				builder.append("Group Time Column Operation on "+groupAction.getColumn().getLabel()+"<br/>");
-//			}
-			
+
 			if(tdDescr!=null){
 				tdActionDescriptions.add(tdDescr);
 			}else
@@ -735,7 +747,7 @@ public class ConverterToTdTemplateModel {
 			
 			FormatReference formatReference = (FormatReference) reference;
 			ValueFormat valueFormat = DataTypeFormats.getFormatPerId(templateColumn.getValueType(), formatReference.getFormatIdentifier());
-			tdColumn.getDataType().setReference(new TdTFormatReference(valueFormat.getId(), valueFormat.getExample()));
+			tdColumn.getDataType().setFormatReference(new TdTFormatReference(valueFormat.getId(), valueFormat.getExample()));
 			
 		}else if(reference instanceof DimensionReference){
 			logger.info("Found column reference as DimensionReference..");
